@@ -5,15 +5,25 @@ A simple dependency injection library.
 
 """
 import functools
-import logging
 
 try:
-    from unittest import mock
+    from unittest import mock as mock_module
 except ImportError:
     try:
-        import mock
+        import mock as mock_module
     except ImportError:
-        mock = None
+        mock_module = None
+
+
+__all__ = [
+    'clear',
+    'DuplicateProviderError',
+    'inject',
+    'Injector',
+    'mock',
+    'provides',
+    'NoCandidateError'
+]
 
 
 _PROVIDERS = {}
@@ -49,18 +59,11 @@ def provides(name):
         init = cls.__init__
 
         def __init__(self, *args, **kwargs):
-            if mock and isinstance(self, mock.Mock):
-                init(self, *args, **kwargs)
-                if name not in _PROVIDERS:
-                    _PROVIDERS[name] = self
-                    logging.info('Mocked [{}]: {}'.format(name, self))
-                return
             if name in _PROVIDERS:
                 raise DuplicateProviderError(
                     'A provider for [{}] already exists'.format(name))
             init(self, *args, **kwargs)
             _PROVIDERS[name] = self
-            logging.info('Injected [{}]: {}'.format(name, self))
 
         try:
             __init__ = functools.wraps(init)(__init__)
@@ -100,6 +103,22 @@ def inject(name):
     return Injector(name)
 
 
+def mock(name, cls=None):
+    """
+    Provide a mock overriding any namespace conflicts.
+
+    Args:
+        name: The name of the mock to provide.
+        cls: The optional mock class to provice.
+
+    """
+    if cls is None:
+        cls = type(name, (mock_module.Mock,), {})
+    instance = cls()
+    _PROVIDERS[name] = instance
+    return instance
+
+
 def clear():
     """
     Clears all current providers.
